@@ -10,7 +10,7 @@ CUPS
 </name>
 
 <description>  
-printing system
+Printing system
 </description>
 
 <installable>
